@@ -51,6 +51,22 @@ Concretlty, it's such as simple as that::
 from constants_and_vars import STATS
 import unicode_csv
 from datetime import datetime
+import unicodedata
+
+def callback_model(self, model, field, line):
+    """Model of the calback signature.
+
+    :param self: Current Session instance
+    :type self: Session
+    :param model: Current model
+    :type model: str
+    :param field: Current field
+    :type field: str
+    :param line: Current line number
+    :type line: int
+
+    """
+    pass
 
 def get_line_from_table(csv_file, value, column, separator=',', quote='"', header=True):
     """Search for an equivalence between value from column ``col_referer``
@@ -147,7 +163,7 @@ def get_value_from_table(csv_file, col_referer=0, col_return=1,
     :type quote: str
     :param header: CSV file has header
     :type header: bool
-    :returns: list
+    :returns: callback_model
 
     """
     def _get_value_from_table(self, model, field, value, line):
@@ -170,7 +186,7 @@ def get_ids(model, fields, op='&'):
     :type field: str
     :param value: The value to compare to
     :type value: str
-    :returns: list
+    :returns: callback_model
 
     """
     def _get_ids(self, b_model, b_field, b_value, b_line):
@@ -212,7 +228,7 @@ def get_id(model, fields, op='&'):
     :type field: str
     :param value: The value to compare to
     :type value: str
-    :returns: int
+    :returns: callback_model
 
     """
     def _get_id(*args):
@@ -233,7 +249,7 @@ def get_objects(model, fields, op='&'):
     :type fields: str
     :param value: The value to compare to
     :type value: str
-    :returns: list
+    :returns: callback_model
 
     """
 
@@ -257,7 +273,7 @@ def get_field(model, fields, field, op='&'):
     :type field: str
     :param value: The value to compare to
     :type value: str
-    :returns: dict
+    :returns: callback_model
 
     """
     
@@ -280,7 +296,7 @@ def get_fields(model, fields, op='&'):
     :type fields: str
     :param value: The value to compare to
     :type value: str
-    :returns: list
+    :returns: callback_model
 
     """
 
@@ -302,7 +318,7 @@ def to_boolean(true='1', false='0', none=''):
     :type true_values: str
     :param false_values: The name of the model's field
     :type false_values: str
-    :returns: bool (or str)
+    :returns: callback_model
 
     """
     def _to_boolean(self, model, field, value, line):
@@ -322,7 +338,7 @@ def to_date(formatted='%Y-%m-%d'):
     
     :param formatted: Format of this date
     :type formatted: str
-    :returns: str
+    :returns: callback_model
 
     """
     def _to_date(self, model, field, value, line):
@@ -338,42 +354,130 @@ def to_date(formatted='%Y-%m-%d'):
 
     return _to_date
 
+def strip_accents(normalize='NFD', uce='Mn'):
+    """Return a accents stripped string
+
+    .. note::
+        
+        This function is a rewriting of unicodedata.normalize
+
+    >>> 'address': Column(3, strip_accent())
+    
+    :param normalize: Normalize code
+    :type normalize: str
+    :param uce: Unicode category exclusion 
+    :type uce: str
+    :returns: callback_model
+
+    """
+    def _strip_accents(self, model, field, value, line):
+        return ''.join((c for c in unicodedata.normalize(normalize, value)
+                    if unicodedata.category(c) != uce))
+
+    return _strip_accents
+
 def city_cedex(res=None, cedex_code=False):
     """Check if a cedex code is in the town name.
     Return the relative string to ``res`` argument
     
-    from 'Paris Cedex 9'
-    >>> 'city':  Column(6, city_cedex('city'))
-    'PARIS'
-    >>> 'cedex': Column(6, city_cedex('cedex'))
-    'CEDEX 9'
+    >>> # initial value for column 6 = 'Paris Cedex 9'
+    >>> 'city':  Column(6, city_cedex('city')) # Returns 'PARIS'
+    >>> 'cedex': Column(6, city_cedex('cedex')) # Returns 'CEDEX 9'
     
     :param res: Relative string returned
     :type res: str
     :param cedex_code: Returns only code or full code ('6', 'CEDEX 6')
     :type cedex_code: str
-    :returns: str or tuple
+    :returns: callback_model
 
     """
     def _city_cedex(self, model, field, value, line):
-        string = value.upper()
-        cedex = ""
+        city = value
+        value = unicode(strip_accents(value.lower()))
+        cedex = u""
 
-        if string.count('CEDEX'):
-            string = string.split('CEDEX')[0].strip(' ')
+        if value.count(u'cedex'):
+            city = value.split(u'cedex')[0]
             try:
-                cedex = "CEDEX %s" % int(string.split('CEDEX')[1].strip(' '))
-            except IndexError:
-                cedex = "CEDEX"
-            except ValueError:
-                cedex = 'CEDEX'
+                cedex = u"cedex %s" % int(value.split(u'cedex')[1])
+            except Exception:
+                cedex = u"cedex"
+        
         if res == 'city':
-            return string
+            return city
         elif res == 'cedex':
             return cedex
         else:
-            return (string, cedex)
+            return (city, cedex)
 
     return _city_cedex
 
+def zfill(*args):
+    """Return a zfilled string.
+
+    .. note::
+        
+        This function is a rewriting of string.zfill, same signature
+
+    >>> 'address': Column(3, zfill(5))
+    
+    :returns: callback_model
+    
+    """
+    def _zfill(self, model ,field, value, line):
+        return value.zfill(*args)
+
+    return _zfill
+
+def upper(*args):
+    """Return a uppered string.
+
+    .. note::
+        
+        This function is a rewriting of string.upper, same signature
+
+    >>> 'address': Column(3, upper())
+    
+    :returns: callback_model
+    
+    """
+    def _upper(self, model ,field, value, line):
+        return value.upper(*args)
+
+    return _upper
+
+def capitalize(*args):
+    """Return a capitalized string.
+
+    .. note::
+        
+        This function is a rewriting of string.capitalize, same signature
+
+    >>> 'address': Column(3, capitalize())
+    
+    :returns: callback_model
+    
+    """
+    def _capitalize(self, model ,field, value, line):
+        return value.capitalize(*args)
+
+    return _capitalize
+
+def strip(*args):
+    """Return a stripped string.
+
+    .. note::
+        
+        This function is a rewriting of string.strip, same signature
+
+    >>> 'address': Column(3, strip())
+    
+    :returns: callback_model
+    
+    """
+    def _strip(self, model ,field, value, line):
+        return value.strip(*args)
+
+    return _strip
+
 
